<?php

/**
 * The Template for displaying product archives, including the main shop page which is a post type archive
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/archive-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 3.4.0
 */

defined('ABSPATH') || exit;

//this action doesnt fire in WooCommerce Controller, leave here
if(is_shop()) {
    remove_action( 'woocommerce_before_shop_loop', 'woocommerce_result_count', 20,0 );
}

get_header('shop');

if(is_shop()) { ?>
    <section class="full-width product-category shop-page" style="background-image: url(<?= get_template_directory_uri() . '/dist/images/background/pilgrims-bg.png'; ?>);">

    <h1 class="shop-title text-center"><?= woocommerce_page_title(); ?></h1>
<?php }
else if(is_product_category()){ ?>
    <section class="full-width product-category category-page" style="background-image: url();">
<?php } ?>
    <div class="woocommerce columns-4 ">

        <?php

        /**
         * Hook: woocommerce_before_main_content.
         *
         * @hooked woocommerce_output_content_wrapper - 10 (outputs opening divs for the content)
         * @hooked woocommerce_breadcrumb - 20
         * @hooked WC_Structured_Data::generate_website_data() - 30
         */
        do_action('woocommerce_before_main_content');

        /**
         * Hook: woocommerce_archive_description.
         *
         * @hooked woocommerce_taxonomy_archive_description - 10
         * @hooked woocommerce_product_archive_description - 10
         */
        do_action('woocommerce_archive_description');

        if (woocommerce_product_loop()) { ?>

            <div class="container">
                <?php
                /**
                 * Hook: woocommerce_before_shop_loop.
                 *
                 * @hooked woocommerce_output_all_notices - 10
                 * @hooked woocommerce_result_count - 20
                 * @hooked woocommerce_catalog_ordering - 30
                 */
                do_action('woocommerce_before_shop_loop'); ?>
            </div>

            <div class="shop-products">
                <div class="container">
                    <?php woocommerce_product_loop_start();

                    if (wc_get_loop_prop('total')) {
                        while (have_posts()) {
                            the_post();

                            /**
                             * Hook: woocommerce_shop_loop.
                             *
                             * @hooked WC_Structured_Data::generate_product_data() - 10
                             */
                            do_action('woocommerce_shop_loop');

                            wc_get_template_part('content', 'product');
                        }
                    }

                    woocommerce_product_loop_end(); ?>
                </div>
            </div>

            <?php

            /**
             * Hook: woocommerce_after_shop_loop.
             *
             * @hooked woocommerce_pagination - 10
             */
            do_action('woocommerce_after_shop_loop');
        } else {
            /**
             * Hook: woocommerce_no_products_found.
             *
             * @hooked wc_no_products_found - 10
             */
            do_action('woocommerce_no_products_found');
        }

        /**
         * Hook: woocommerce_after_main_content.
         *
         * @hooked woocommerce_output_content_wrapper_end - 10 (outputs closing divs for the content)
         */
        do_action('woocommerce_after_main_content');

        /**
         * Hook: woocommerce_sidebar.
         *
         * @hooked woocommerce_get_sidebar - 10
         */
        do_action('woocommerce_sidebar');
        ?>

    </div>
    </section>

<?php

if(is_shop() ) {
    if (have_rows('sections' , get_option( 'woocommerce_shop_page_id' ))) {
        while (have_rows('sections' , get_option( 'woocommerce_shop_page_id' ))) {
            the_row();
            get_template_part('templates/sections/' . get_row_layout());
        }
    }
}
else {
    $term = get_queried_object();
    if (have_rows('sections' , $term)) {
        while (have_rows('sections' , $term)) {
            the_row();
            get_template_part('templates/sections/' . get_row_layout());
        }
    }
}

get_footer('shop');
